@@ -82,15 +82,12 @@ struct _GnomePilotCappletPrivate
 	GtkWidget *conduit_popup_disable;
 	GtkWidget *conduit_popup_settings;	
 	GtkWidget *conduit_description;
-
-	GtkWidget *sync_pcid;
 };
 
 static void class_init (GnomePilotCappletClass *klass);
 static void init (GnomePilotCapplet *gpcap);
 
 static gboolean get_widgets (GnomePilotCapplet *gpcap);
-static void map_widgets (GnomePilotCapplet *gpcap);
 static void init_widgets (GnomePilotCapplet *gpcap);
 static void fill_widgets (GnomePilotCapplet *gpcap);
 
@@ -117,9 +114,7 @@ static void gpcap_conduits_settings (GtkWidget *widget, gpointer user_data);
 static gboolean gpcap_conduits_popup (GtkTreeView *treeview, GdkEventButton *event, gpointer user_data);
 static void gpcap_conduits_selection_changed (GtkTreeSelection *selection, gpointer user_data);
 
-static void gpcap_cap_try (GtkWidget *widget, gpointer user_data);
-
-static void gpcap_changed (GtkWidget *widget, gpointer user_data);
+static void gpcap_save_state (GnomePilotCapplet *gpcap);
 
 static void gpcap_dispose (GObject *object);
 
@@ -163,7 +158,6 @@ static void
 init (GnomePilotCapplet *gpcap)
 {
 	GnomePilotCappletPrivate *priv;
-	GtkWidget *window;
 	
 	priv = g_new0 (GnomePilotCappletPrivate, 1);
 
@@ -185,7 +179,6 @@ init (GnomePilotCapplet *gpcap)
 		goto error;
 	}
 	
-	map_widgets (gpcap);
 	fill_widgets (gpcap);
 	init_widgets (gpcap);
 
@@ -197,7 +190,7 @@ gnome_pilot_capplet_new (GnomePilotClient *gpc)
 {
 	GnomePilotCapplet *gpcap;
 	
-	gpcap = g_object_new (GNOME_PILOT_TYPE_CAPPLET, NULL);
+	gpcap = g_object_new (GNOME_PILOT_TYPE_CAPPLET, "default-height", 350, "default-width", 350, NULL);
 	
 	gpcap->priv->gpc = gpc;
 
@@ -247,8 +240,6 @@ get_widgets (GnomePilotCapplet *gpcap)
 	priv->conduit_settings = GW ("conduit_settings_button");
 	priv->conduit_description = GW ("description_label");
 	
-	priv->sync_pcid = GW ("syncpcid_entry");
-	
 #undef GW
 	return (priv->notebook
 		&& priv->pilots_treeview
@@ -264,19 +255,7 @@ get_widgets (GnomePilotCapplet *gpcap)
 		&& priv->conduit_enable
 		&& priv->conduit_disable
 		&& priv->conduit_settings
-		&& priv->conduit_description		
-		&& priv->sync_pcid);
-}
-
-static void
-map_widgets (GnomePilotCapplet *gpcap)
-{
-	GnomePilotCappletPrivate *priv;
-	
-	priv = gpcap->priv;
-
-	
-	g_object_set_data (G_OBJECT (gpcap), "syncpcid_entry", priv->sync_pcid);
+		&& priv->conduit_description);
 }
 
 static void 
@@ -313,10 +292,6 @@ init_widgets (GnomePilotCapplet *gpcap)
 
 	gtk_signal_connect (GTK_OBJECT (priv->conduit_settings), "clicked",
 			    GTK_SIGNAL_FUNC (gpcap_conduits_settings), gpcap);
-	
-	/* Change signals */
-	gtk_signal_connect (GTK_OBJECT (priv->sync_pcid), "changed",
-			    GTK_SIGNAL_FUNC (gpcap_changed), gpcap);
 
 	/* Row selection signals */
 	g_signal_connect (gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->pilots_treeview)), "changed",
@@ -355,8 +330,7 @@ append_pilots_treeview (GnomePilotCapplet *gpcap, GPilotPilot *pilot, GtkTreeIte
 			    0, pilot->name,
 			    1, pilot->pilot_id,
 			    2, pilot->pilot_username,
-			    3, sync_type_to_str (pilot->sync_options.default_sync_action),
-			    4, pilot,
+			    3, pilot,
 			    -1);
 }
 
@@ -378,6 +352,8 @@ fill_pilots_treeview (GnomePilotCapplet *gpcap)
 	}	
 }
 
+GtkWidget* gnome_pilot_capplet_create_pilots_treeview (char *name, char *string1, char *string2, int num1, int num2);
+
 GtkWidget*
 gnome_pilot_capplet_create_pilots_treeview (char *name, char *string1, char *string2, int num1, int num2)
 {
@@ -385,7 +361,6 @@ gnome_pilot_capplet_create_pilots_treeview (char *name, char *string1, char *str
 	GtkTreeSelection *selection;
 	GtkCellRenderer *renderer;
 	GtkListStore *model;
-	char *titles[2];
 
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
@@ -393,7 +368,7 @@ gnome_pilot_capplet_create_pilots_treeview (char *name, char *string1, char *str
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
 					     GTK_SHADOW_IN);
 
-	model = gtk_list_store_new (5, G_TYPE_STRING, G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
+	model = gtk_list_store_new (4, G_TYPE_STRING, G_TYPE_INT, G_TYPE_STRING, G_TYPE_POINTER);
 	treeview = gtk_tree_view_new_with_model ((GtkTreeModel *) model);
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -403,8 +378,6 @@ gnome_pilot_capplet_create_pilots_treeview (char *name, char *string1, char *str
 						     renderer, "text", 1, NULL);
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview), -1, _("UserName"),
 						     renderer, "text", 2, NULL);
-	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview), -1, _("Sync Type"),
-						     renderer, "text", 3, NULL);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
@@ -461,6 +434,8 @@ fill_devices_treeview (GnomePilotCapplet *gpcap)
 	}	
 }
 
+GtkWidget *gnome_pilot_capplet_create_devices_treeview (char *name, char *string1, char *string2, int num1, int num2);
+
 GtkWidget*
 gnome_pilot_capplet_create_devices_treeview (char *name, char *string1, char *string2, int num1, int num2)
 {
@@ -468,7 +443,6 @@ gnome_pilot_capplet_create_devices_treeview (char *name, char *string1, char *st
 	GtkTreeSelection *selection;
 	GtkCellRenderer *renderer;
 	GtkListStore *model;
-	char *titles[2];
 
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
@@ -572,6 +546,8 @@ set_conduit_pilot (GnomePilotCapplet *gpcap, GPilotPilot *pilot)
 	check_conduits_buttons (gpcap);
 }
 
+GtkWidget *gnome_pilot_capplet_create_conduit_treeview (char *name, char *string1, char *string2, int num1, int num2);
+
 GtkWidget*
 gnome_pilot_capplet_create_conduit_treeview (char *name, char *string1, char *string2, int num1, int num2)
 {
@@ -579,7 +555,6 @@ gnome_pilot_capplet_create_conduit_treeview (char *name, char *string1, char *st
 	GtkTreeSelection *selection;
 	GtkCellRenderer *renderer;
 	GtkListStore *model;
-	char *titles[2];
 
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
@@ -647,7 +622,6 @@ static void
 fill_widgets (GnomePilotCapplet *gpcap)
 {
 	GnomePilotCappletPrivate *priv;
-	gchar buf[40];
 
 	priv = gpcap->priv;
 	
@@ -661,10 +635,6 @@ fill_widgets (GnomePilotCapplet *gpcap)
 
 	/* Conduits page */
 	fill_pilots_menu (gpcap);
-
-	/* Advanced page */
-	g_snprintf (buf, sizeof (buf), "%d", priv->state ? priv->state->syncPCid : 0);
-	gtk_entry_set_text (GTK_ENTRY (priv->sync_pcid), buf);
 }
 
 void
@@ -683,16 +653,6 @@ gnome_pilot_capplet_update (GnomePilotCapplet *gpcap)
 	fill_widgets (gpcap);
 }
 
-static void
-gpcap_set_changed_state (GnomePilotCapplet *gpcap)
-{
-	GnomePilotCappletPrivate *priv;
-
-	priv = gpcap->priv;
-
-	gpcap_cap_try (NULL, gpcap);
-}
-
 static void
 check_pilots_buttons (GnomePilotCapplet *gpcap) 
 {
@@ -725,7 +685,7 @@ get_current_pilot (GnomePilotCapplet *gpcap, GtkTreeIter *iter)
 		return NULL;
 
 	gtk_tree_model_get (priv->pilots_model, iter,
-			    4, &pilot,
+			    3, &pilot,
 			    -1);
 
 	return pilot;
@@ -760,7 +720,7 @@ gpcap_pilots_add (GtkWidget *widget, gpointer user_data)
 		
 		fill_pilots_menu (gpcap);
 		
-		gpcap_set_changed_state (gpcap);
+		gpcap_save_state (gpcap);
 	}
 }
 
@@ -786,12 +746,11 @@ gpcap_pilots_edit (GtkWidget *widget, gpointer user_data)
 				    0, pilot->name,
 				    1, pilot->pilot_id,
 				    2, pilot->pilot_username,
-				    3, sync_type_to_str (pilot->sync_options.default_sync_action),
 				    -1);
 			
 		fill_pilots_menu (gpcap);
 		
-		gpcap_set_changed_state (gpcap);
+		gpcap_save_state (gpcap);
 	}
 }
 
@@ -800,6 +759,7 @@ gpcap_pilots_delete (GtkWidget *widget, gpointer user_data)
 {
 	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (user_data);
 	GnomePilotCappletPrivate *priv;
+	GtkWidget *dlg;
 	GPilotPilot *pilot;
 	GtkTreeIter iter;
 	
@@ -807,16 +767,22 @@ gpcap_pilots_delete (GtkWidget *widget, gpointer user_data)
 	
 	pilot = get_current_pilot (gpcap, &iter);
 
-	if (yes_no_dialog (_("Are you sure you want to delete %s pilot?"), pilot->name)) {
+	dlg = gtk_message_dialog_new (GTK_WINDOW (gpcap), GTK_DIALOG_DESTROY_WITH_PARENT, 
+				      GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
+				      _("Are you sure you want to delete %s pilot?"), pilot->name);
+
+	if (gtk_dialog_run (GTK_DIALOG (dlg)) == GTK_RESPONSE_YES) {
 		gtk_list_store_remove (GTK_LIST_STORE (priv->pilots_model),
 				       &iter);
 		priv->state->pilots = g_list_remove (priv->state->pilots, pilot);
 		
 		fill_pilots_menu (gpcap);
 		
-		gpcap_set_changed_state (gpcap);
+		gpcap_save_state (gpcap);
 	}
 
+	gtk_widget_destroy (dlg);
+	
 	check_pilots_buttons (gpcap);
 }
 
@@ -918,7 +884,7 @@ gpcap_devices_add (GtkWidget *widget, gpointer user_data)
 		gtk_tree_selection_select_iter (gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->devices_treeview)),
 						&iter);
 		
-		gpcap_set_changed_state (gpcap);
+		gpcap_save_state (gpcap);
 	}
 }
 
@@ -947,7 +913,7 @@ gpcap_devices_edit (GtkWidget *widget, gpointer user_data)
 				    3, device_type_to_str (device->type),
 				    -1);
 		
-		gpcap_set_changed_state (gpcap);
+		gpcap_save_state (gpcap);
 	}
 }
 
@@ -956,6 +922,7 @@ gpcap_devices_delete (GtkWidget *widget, gpointer user_data)
 {
 	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (user_data);
 	GnomePilotCappletPrivate *priv;
+	GtkWidget *dlg;
 	GPilotDevice *device;
 	GtkTreeIter iter;
 	
@@ -963,13 +930,19 @@ gpcap_devices_delete (GtkWidget *widget, gpointer user_data)
 	
 	device = get_current_device (gpcap, &iter);
 
-	if (yes_no_dialog (_("Are you sure you want to delete %s pilot?"), device->name)) {
+	dlg = gtk_message_dialog_new (GTK_WINDOW (gpcap), GTK_DIALOG_DESTROY_WITH_PARENT, 
+				      GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
+				      _("Are you sure you want to delete %s device?"), device->name);
+
+	if (gtk_dialog_run (GTK_DIALOG (dlg)) == GTK_RESPONSE_YES) {
 		gtk_list_store_remove (GTK_LIST_STORE (priv->devices_model),
 				       &iter);
 		priv->state->devices = g_list_remove (priv->state->devices, device);
-		gpcap_set_changed_state (gpcap);
+		gpcap_save_state (gpcap);
 	}
 
+	gtk_widget_destroy (dlg);
+	
 	check_devices_buttons (gpcap);
 }
 
@@ -1098,7 +1071,7 @@ gpcap_conduits_enable (GtkWidget *widget, gpointer user_data)
 			    -1);
 
 	check_conduits_buttons (gpcap);
-	gpcap_set_changed_state (gpcap);
+	gpcap_save_state (gpcap);
 
 	gpcap_conduits_settings (widget, user_data);
 }
@@ -1109,7 +1082,6 @@ gpcap_conduits_disable (GtkWidget *widget, gpointer user_data)
 	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (user_data);
 	GnomePilotCappletPrivate *priv;
 	ConduitState *state;
-	gint row;
 	GtkTreeIter iter;
 
 	priv = gpcap->priv;
@@ -1125,7 +1097,7 @@ gpcap_conduits_disable (GtkWidget *widget, gpointer user_data)
 			    -1);
 
 	check_conduits_buttons (gpcap);
-	gpcap_set_changed_state (gpcap);
+	gpcap_save_state (gpcap);
 }
 
 static void 
@@ -1148,7 +1120,7 @@ gpcap_conduits_settings (GtkWidget *widget, gpointer user_data)
 		    != GNOME_PILOT_CONDUIT_MGMT_OK) {
 			
 			gchar *msg = _("Unable to instantiate %s conduit.");
-			error_dialog (msg, state->name);
+			error_dialog (GTK_WINDOW (gpcap), msg, state->name);
 			return;
 		}
 
@@ -1167,7 +1139,7 @@ gpcap_conduits_settings (GtkWidget *widget, gpointer user_data)
 					    1, display_sync_type_name (state->enabled, state->sync_type),
 					    -1);
 			
-			gpcap_set_changed_state (gpcap);
+			gpcap_save_state (gpcap);
 		} else {
 			/* pressed cancel */
 			gnome_pilot_conduit_display_settings (state->conduit);
@@ -1184,7 +1156,6 @@ gpcap_conduits_popup (GtkTreeView *treeview, GdkEventButton *event, gpointer use
 	GnomePilotCappletPrivate *priv;
 	ConduitState *state;
 	GtkTreePath *path;
-	GtkTreeIter iter;
 	gboolean test = FALSE, enabled = FALSE;
 	
 	GnomeUIInfo popup [] = {
@@ -1286,68 +1257,18 @@ conduit_try_foreach (gpointer key, gpointer value, gpointer func)
 }
 
 static void 
-gpcap_cap_try (GtkWidget *widget, gpointer user_data)
+gpcap_save_state (GnomePilotCapplet *gpcap)
 {
-	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (user_data);
 	GnomePilotCappletPrivate *priv;
-	GList *tmp;
 	
-	priv = gpcap->priv;
-	
-	read_host_config (G_OBJECT (gpcap), priv->state);
+	priv = gpcap->priv;	
 
-	tmp = priv->state->devices;
-	while (tmp!= NULL) {
-		GPilotDevice *device = (GPilotDevice*)tmp->data;
-		check_device_settings (device);
-		tmp = tmp->next;
-	}
-
-	g_hash_table_foreach (priv->conduits, conduit_try_foreach, NULL);
+	if (priv->conduits != NULL)
+		g_hash_table_foreach (priv->conduits, conduit_try_foreach, NULL);
 	
 	save_config_and_restart (priv->gpc, priv->state);
 }
 
-static void
-conduit_revert_foreach (gpointer key, gpointer value, gpointer func)
-{
-	GList *states = (GList*)value;
-	
-	while (states != NULL) {
-		ConduitState *state = (ConduitState*)states->data;
-		
-		if (state->changed && state->orig_enabled) {
-			if (state->orig_sync_type == GnomePilotConduitSyncTypeCustom)
-				gnome_pilot_conduit_config_enable (state->config, GnomePilotConduitSyncTypeCustom);
-			else
-				 gnome_pilot_conduit_config_enable (state->config, state->orig_sync_type);
-			
-			state->enabled = state->orig_enabled;
-			state->sync_type = state->orig_sync_type;
-			state->first_sync_type = state->orig_first_sync_type;
-		}
-		
-		if (state->changed && !state->orig_enabled) {
-			gnome_pilot_conduit_config_disable (state->config);
-			
-			state->enabled = state->orig_enabled;
-		}
-		
-		if (state->conduit && state->changed)
-			gnome_pilot_conduit_revert_settings (state->conduit);
-		
-		states = states->next;
-	}
-}
-
-static void
-gpcap_changed (GtkWidget *widget, gpointer user_data)
-{
-	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (user_data);
-
-	gpcap_set_changed_state (gpcap);
-}
-
 static void
 gpcap_dispose (GObject *object)
 {
