@@ -55,7 +55,6 @@ struct _GnomePilotPDialogPrivate
 
 	GtkWidget *pilot_name;
 	GtkWidget *pilot_basedir;
-	GtkWidget *pilot_sync_type;
 
 	GtkWidget *sync_dialog;
 };
@@ -194,7 +193,6 @@ get_widgets (GnomePilotPDialog *gppd)
 	
 	priv->pilot_name = GW ("pilot_name_entry");
 	priv->pilot_basedir = GW ("pilot_basedir_entry");
-	priv->pilot_sync_type = GW ("sync_type_menu");
 	
 #undef GW
 	return (priv->dialog
@@ -203,8 +201,7 @@ get_widgets (GnomePilotPDialog *gppd)
 		&& priv->pilot_get
 		&& priv->pilot_send
 		&& priv->pilot_name
-		&& priv->pilot_basedir
-		&& priv->pilot_sync_type);
+		&& priv->pilot_basedir);
 }
 
 static void
@@ -218,7 +215,6 @@ map_widgets (GnomePilotPDialog *gppd)
 	gtk_object_set_data (GTK_OBJECT (gppd), "pilotid", priv->pilot_id);
 	gtk_object_set_data (GTK_OBJECT (gppd), "pilotname", priv->pilot_name);
 	gtk_object_set_data (GTK_OBJECT (gppd), "basedir", priv->pilot_basedir);
-	gtk_object_set_data (GTK_OBJECT (gppd), "sync_menu", priv->pilot_sync_type);
 }
 
 static void 
@@ -258,8 +254,6 @@ fill_widgets (GnomePilotPDialog *gppd)
 
 		gtk_entry_set_text (GTK_ENTRY (priv->pilot_name), priv->pilot->name);
 		gtk_entry_set_text (GTK_ENTRY (priv->pilot_basedir), priv->pilot->sync_options.basedir);
-
-		fill_synctype_menu (GTK_OPTION_MENU (priv->pilot_sync_type), priv->pilot->sync_options.default_sync_action);
 	}
 }
 
@@ -409,7 +403,7 @@ gppd_pilot_get (GtkWidget *widget, gpointer user_data)
 							&priv->handle2) == GPILOTD_OK) {
 			gppd_sync_dialog (gppd, dev);
 		} else {
-			error_dialog (_("The request to get pilot id failed"));
+			error_dialog (GTK_WINDOW (priv->dialog), _("The request to get pilot id failed"));
 		}
 	}
 }
@@ -448,7 +442,7 @@ gppd_pilot_send (GtkWidget *widget, gpointer user_data)
 							&priv->handle2) == GPILOTD_OK) {
 			gppd_sync_dialog (gppd, dev);
 		} else {
-			error_dialog (_("The request to set pilot id failed"));
+			error_dialog (GTK_WINDOW (priv->dialog), _("The request to set pilot id failed"));
 		}
 		gpilot_pilot_free (pilot);	
 	}
