@@ -32,14 +32,13 @@
 #include <gnome.h>
 #include <glade/glade.h>
 
-#include <capplet-widget.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include <gpilotd/gnome-pilot-client.h>
 
 #include "gnome-pilot-druid.h"
 #include "gnome-pilot-capplet.h"
 
-#include <libgnorba/gnorba.h>
+#include <bonobo-activation/bonobo-activation.h>
 
 #include "pilot.h"
 #include "util.h"
@@ -65,9 +64,7 @@ main (int argc, char *argv[])
 {
 	GnomePilotClient *gpc = NULL;
 	PilotState *state = NULL;
-
-	GtkWidget *gpcap = NULL, *gpcc = NULL;
-	GtkWidget *capplet = NULL;
+	GnomePilotCapplet *gpcap = NULL;
 	gboolean druid_on = FALSE, druid_prog = FALSE;
 
 	struct poptOption options[] = {
@@ -79,20 +76,19 @@ main (int argc, char *argv[])
 	
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	
 	if (argc > 1 && strcmp (argv[1], "--druid") == 0) {
-		/* we are a regular gnome app with CORBA support */
-		CORBA_Environment ev;
-		gnome_CORBA_init_with_popt_table ("gpilot control applet",
-						 VERSION, &argc, argv,
-						 options,0,NULL,0,&ev);
+		gnome_init_with_popt_table ("gpilot-control-applet",
+					    VERSION, argc, argv,
+					    options,0,NULL);
 
 		druid_on = TRUE;
 		druid_prog = TRUE;
 	} else {
 		/* we're a capplet (we get CORBA for free from capplet_init) */
-		switch (gnome_capplet_init ("gpilot control applet", VERSION, argc, argv, 
-					   options,0,NULL)) {
+		switch (gnome_init_with_popt_table ("gpilotd-control-applet", VERSION, argc, argv, 
+						    options,0,NULL)) {
 		case 1: return 0; break;
 		case -1: g_error (_("Error initializing gpilotd capplet")); break;
 		default: break;
@@ -105,7 +101,7 @@ main (int argc, char *argv[])
 	
 	/* put all code to set things up in here */
 	if (loadPilotState (&state) < 0) {
-		error_dialog (_("Error loading pilot state, aborting"));
+		error_dialog (NULL, _("Error loading pilot state, aborting"));
 		g_error (_("Error loading pilot state, aborting"));
 		return -1;
 	}
@@ -113,7 +109,7 @@ main (int argc, char *argv[])
 	gpc = GNOME_PILOT_CLIENT (gnome_pilot_client_new ());
 
 	if (gnome_pilot_client_connect_to_daemon (gpc) != GPILOTD_OK) {
-		error_dialog (_("Cannot connect to the GnomePilot Daemon"));
+		error_dialog (NULL,_("Cannot connect to the GnomePilot Daemon"));
 		g_error (_("Cannot connect to the GnomePilot Daemon"));
 		return -1;
 	}
@@ -123,35 +119,35 @@ main (int argc, char *argv[])
 		GtkObject *druid;
 		
 		if (state->pilots!= NULL || state->devices!= NULL) {
-			error_dialog (_("Cannot run druid if pilots or cradles already configured"));
+			error_dialog (NULL, _("Cannot run druid if pilots or cradles already configured"));
 			return -1;
 		}
 
 		druid = gnome_pilot_druid_new (gpc);
 		gnome_pilot_druid_run_and_close (GNOME_PILOT_DRUID (druid));
 	} else {
+		gboolean druid_finished = TRUE;
 		
-		capplet = capplet_widget_new ();
-
 		gpcap = gnome_pilot_capplet_new (gpc);
-		gtk_container_add (GTK_CONTAINER (capplet), gpcap);
-		gnome_pilot_capplet_set_parent (GNOME_PILOT_CAPPLET (gpcap), CAPPLET_WIDGET (capplet));
 
-		gtk_widget_show_all (capplet);
-	
+		/* quit when the Close button is clicked on our dialog */
+		gtk_signal_connect (GTK_OBJECT (gpcap), "response", GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
+
 		/* popup the druid if nothing is configured - assume this is the first time */
 		if (state->pilots == NULL && state->devices == NULL) {
 			GtkObject *druid;
 			
 			druid = gnome_pilot_druid_new (gpc);
-			gnome_pilot_druid_run_and_close (GNOME_PILOT_DRUID (druid));
+			druid_finished = gnome_pilot_druid_run_and_close (GNOME_PILOT_DRUID (druid));
 
 			if (gpcap != NULL)
 				gnome_pilot_capplet_update (GNOME_PILOT_CAPPLET (gpcap));
 		}
 
-		/* done setting up, now run main loop */
-		capplet_gtk_main ();
+		if (druid_finished) {
+			gtk_widget_show (GTK_WIDGET (gpcap));
+			gtk_main ();
+		}		
 	}
 	freePilotState (state);
 
