@@ -75,31 +75,6 @@ fill_speed_menu (GtkOptionMenu *option_menu, guint default_speed)
 	gtk_option_menu_set_history (option_menu, n);
 }
 
-void
-fill_synctype_menu (GtkOptionMenu *option_menu, GnomePilotConduitSyncType type)
-{
-	GtkMenu *menu;
-	GtkWidget *menu_item;
-	int i;
-	int choice = 0;
-	
-	menu = GTK_MENU (gtk_menu_new ());
-
-	for (i = 0; synctypes[i] != NULL; i++) {
-		menu_item = gtk_menu_item_new_with_label (synctypes[i]);
-		gtk_widget_show (menu_item);
-		gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (syncvalues[i]));
-		gtk_menu_append (menu, menu_item);
-
-		if (type == syncvalues[i]) {
-			choice = i;
-		}			
-	}
-
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu),GTK_WIDGET (menu));
-	gtk_option_menu_set_history (option_menu, choice);
-}
-
 void 
 fill_conduit_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state)
 {
@@ -172,23 +147,28 @@ fill_conduit_first_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *sta
 	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), current);
 }
 
-void
-show_popup_menu (GtkCList *list, GdkEventButton *event, GtkMenu *menu)
+gboolean
+show_popup_menu (GtkTreeView *treeview, GdkEventButton *event, GtkMenu *menu)
 {
 	if (event && event->button ==3) {
-		gint  row, col;
-		
-		if (gtk_clist_get_selection_info (list, event->x, event->y, &row, &col)) {
-			gtk_clist_select_row (list, row, 0);
-			
+		GtkTreePath *path;
+
+		if (gtk_tree_view_get_path_at_pos (treeview, event->x, event->y, &path,
+						   NULL, NULL, NULL)) {
+			gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview),
+							path);
+			gtk_tree_path_free (path);
+
 			gtk_menu_popup (menu, NULL, NULL, NULL, NULL, 
 					event->button, event->time);
 		}
 	}
+
+	return FALSE;
 }
 
 void 
-error_dialog (gchar *mesg, ...) 
+error_dialog (GtkWindow *parent, gchar *mesg, ...) 
 {
 	GtkWidget *dlg;
 	char *tmp;
@@ -196,31 +176,16 @@ error_dialog (gchar *mesg, ...)
 
 	va_start (ap,mesg);
 	tmp = g_strdup_vprintf (mesg,ap);
-	dlg = gnome_message_box_new (tmp,GNOME_MESSAGE_BOX_ERROR,GNOME_STOCK_BUTTON_OK,NULL);
-	gnome_dialog_run_and_close (GNOME_DIALOG (dlg));
+
+	dlg = gtk_message_dialog_new (parent, GTK_DIALOG_DESTROY_WITH_PARENT, 
+				      GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, tmp);
+	gtk_dialog_run (GTK_DIALOG (dlg));
+	gtk_widget_destroy (dlg);
+	
 	va_end (ap);
 	g_free (tmp);
 }
 
-gboolean
-yes_no_dialog (gchar *mesg,...) 
-{
-	GtkWidget *dlg;
-	char *tmp;
-	gint button;
-	va_list ap;
-  
-	va_start (ap,mesg);
-	tmp = g_strdup_vprintf (mesg,ap);
-	dlg = gnome_message_box_new (tmp,GNOME_MESSAGE_BOX_QUESTION,
-				     GNOME_STOCK_BUTTON_YES,GNOME_STOCK_BUTTON_NO,NULL);
-	button = gnome_dialog_run_and_close (GNOME_DIALOG (dlg));
-	va_end (ap);
-	g_free (tmp);
-
-	return button == 0 ? TRUE : FALSE;
-}
-
 static GPilotDevice *
 real_choose_pilot_dialog (PilotState *state) 
 {
@@ -230,7 +195,7 @@ real_choose_pilot_dialog (PilotState *state)
 	GList *tmp;
 	GPilotDevice *dev;
 	
-	xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "ChooseDevice");	
+	xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "ChooseDevice", NULL);
 	dlg = glade_xml_get_widget (xml,"ChooseDevice");
 	option_menu = glade_xml_get_widget (xml, "device_menu");
 
@@ -266,7 +231,7 @@ choose_pilot_dialog (PilotState *state)
 	GPilotDevice *dev = NULL;
 
 	if (state->devices == NULL)
-		error_dialog (_("You must have at least one device setup"));
+		error_dialog (NULL, _("You must have at least one device setup"));
 	else if (g_list_length (state->devices) == 1)
 		dev = (GPilotDevice*)state->devices->data;
 	else
@@ -342,7 +307,7 @@ insert_device_callback (GtkEditable *editable, const gchar *text,
 			gint len, gint *position, void *data)
 {
 	gint i;
-	gchar *curname;
+	const gchar *curname;
 
 	curname = gtk_entry_get_text (GTK_ENTRY (editable));
 	if (*curname == '\0' && len > 0) {
@@ -373,17 +338,6 @@ check_editable (GtkEditable *editable)
 	return test;
 }
 
-gboolean
-check_selection (GtkCList *clist)
-{
-	gboolean test = TRUE;
-
-	if (clist->selection == NULL)
-		test = FALSE;
-
-	return test;
-}
-
 /* find the next "Cradle#" name that is available for use */
 
 static gint compare_device_name (GPilotDevice *device, gchar *name)
@@ -488,7 +442,7 @@ check_device_info (GPilotDevice* device1, GPilotDevice *device2)
 }
 
 gboolean
-check_base_directory (gchar *dir_name)
+check_base_directory (const gchar *dir_name)
 {
 	gboolean ret = TRUE;
 	/* check basedir validity */
@@ -501,30 +455,30 @@ check_base_directory (gchar *dir_name)
 			stat (dir_name, &buf);
 			if (S_ISDIR (buf.st_mode)) {  
 				if (!(buf.st_mode & (S_IRUSR | S_IWUSR |S_IXUSR))) {
-					error_dialog (_("The specified base directory exists but has the wrong permissions.\n"
+					error_dialog (NULL, _("The specified base directory exists but has the wrong permissions.\n"
 							"Please fix or choose another directory"));
 					ret = FALSE;
 				}
 			} else {
-				error_dialog (_("The specified base directory exists but is not a directory.\n"
+				error_dialog (NULL, _("The specified base directory exists but is not a directory.\n"
 						"Please make it a directory or choose another directory"));
 				ret = FALSE;
 			}
 			break;
 			
 		case EACCES:
-			error_dialog (_("It wasn't possible to create the specified base directory.\n"
+			error_dialog (NULL, _("It wasn't possible to create the specified base directory.\n"
 					"Please verify the permitions on the specified path or choose another directory"));
 			ret = FALSE;
 			break;
 		case ENOENT:
-			error_dialog (_("The path specified for the base directory is invalid.\n"
+			error_dialog (NULL, _("The path specified for the base directory is invalid.\n"
 					"Please choose another directory"));
 			ret = FALSE;
 			break;
 		default:
 			errstr = strerror (errno);
-			error_dialog (errstr);
+			error_dialog (NULL, errstr);
 			ret = FALSE;
 		}
 	}
@@ -576,7 +530,7 @@ void
 read_pilot_config (GtkObject *object, GPilotPilot *pilot)
 {
 	GtkWidget *id, *name, *pname, *basedir, *menu;
-	gchar *num;
+	const gchar *num;
 	gint pilotid;
 	g_return_if_fail (pilot!= NULL);
 
@@ -601,20 +555,6 @@ read_pilot_config (GtkObject *object, GPilotPilot *pilot)
 	if (pilot->sync_options.basedir) 
 		g_free (pilot->sync_options.basedir);
 	pilot->sync_options.basedir = g_strdup (gtk_entry_get_text (GTK_ENTRY (basedir)));
-	pilot->sync_options.default_sync_action = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (object),"sync_type"));
-}
-
-void
-read_host_config (GtkObject *object, PilotState *state)
-{
-	GtkWidget *entry;
-	gchar *buf;
-
-	entry = gtk_object_get_data (GTK_OBJECT (object), "syncpcid_entry");
-	if (entry) {
-		buf = gtk_entry_get_text (GTK_ENTRY (entry));
-		state->syncPCid = strtol (buf, NULL, 10);
-	}
 }
 
 void 
@@ -625,7 +565,7 @@ save_config_and_restart (GnomePilotClient *gpc, PilotState *state)
 	gnome_pilot_client_restart_daemon (gpc);
 }
 
-void 
+gboolean
 check_device_settings (GPilotDevice *device)
 {
 	char *str;
@@ -636,10 +576,10 @@ check_device_settings (GPilotDevice *device)
 			str = g_strdup_printf ("%s\n%s (%s)\n%s",
 					       _("Read/Write permissions failed on"),
 					       device->name, device->port,
-					       _("Check the permissions on the device and retry"));	  
-			error_dialog (str);
+					       _("Check the permissions on the device and retry"));
+			error_dialog (NULL, str);
 			g_free (str);
-			return ;
+			return FALSE;
 		}
 	} else if (device->type == PILOT_DEVICE_USB_VISOR) {
 		struct stat sb;
@@ -650,17 +590,18 @@ check_device_settings (GPilotDevice *device)
 					       device->name, device->port,
 					       _("The port should point to a USB serial port"),
 					       g_strerror (errno), errno);	  
-			error_dialog (str);
+			error_dialog (NULL, str);
 			g_free (str);
-			return ;
+			return FALSE;
 		} else if (!S_ISCHR (sb.st_mode)) {
 			str = g_strdup_printf ("%s\n%s (%s)",
 					       _("The port should be a character special device but isn't for"),
 					       device->name, device->port);
-			error_dialog (str);
+			error_dialog (NULL, str);
 			g_free (str);
-			return ;
+			return FALSE;
 		}
 	}
 
+	return TRUE;
 }
