@@ -479,69 +479,18 @@ do_sync (int pfd,
 	   restores etc. If this returns True, continue with normal conduit running,
 	   if False, don't proceed */
 	if (gpilot_initial_synchronize_operations (pfd,
-						  &stamp,
-						  pu,
-						  conduit_list,
-						  backup_conduit_list,
-						  file_conduit_list,
-						  device,
-						  context)) {
-
-		/* FIXME: We need to actually pass a different structure to these
-		   functions containing the pu item and the pilot pointer so that
-		   we can store the lastSyncPC and assorted fields in
-		   ~/.gnome_private/gnome-pilot.d/gpilotd. We will also need some
-		   lock mechanism when we start forking for that file :)*/
-		switch (pilot->sync_options.default_sync_action) {
-		case GnomePilotConduitSyncTypeSynchronize:
-			g_message (_("Synchronizing..."));
-			gpilot_synchronize (pfd,&stamp,pu,
-					   conduit_list,
-					   backup_conduit_list,
-					   file_conduit_list,
-					   context);
-			break;
-		case GnomePilotConduitSyncTypeCopyToPilot:
-			g_message (_("Copying to pilot..."));
-			gpilot_copy_to_pilot (pfd,&stamp,pu,
-					     conduit_list,
-					     backup_conduit_list,
-					     file_conduit_list,
-					     context);
-			break;
-		case GnomePilotConduitSyncTypeCopyFromPilot:
-			g_message (_("Copying from pilot..."));
-			gpilot_copy_from_pilot (pfd,&stamp,pu,
-					       conduit_list,
-					       backup_conduit_list,
-					       context);
-			break;
-		case GnomePilotConduitSyncTypeMergeToPilot:
-			g_message (_("Merging to pilot..."));
-			gpilot_merge_to_pilot (pfd,&stamp,pu,
-					      conduit_list,
-					      backup_conduit_list,
-					      file_conduit_list,
-					      context);
-			break;
-		case GnomePilotConduitSyncTypeMergeFromPilot:
-			g_message (_("Merging from pilot..."));
-			gpilot_merge_from_pilot (pfd,&stamp,pu,
-						conduit_list,
-						backup_conduit_list,
-						context);
-			break;
-		case GnomePilotConduitSyncTypeNotSet:
-		case GnomePilotConduitSyncTypeCustom:
-		default:
-			g_message (_("Using conduit settings for sync..."));
-			gpilot_sync_default (pfd,&stamp,pu,
-					    conduit_list,
-					    backup_conduit_list,
-					    file_conduit_list,
-					    context);
-			break;
-		}
+						   &stamp,
+						   pu,
+						   conduit_list,
+						   backup_conduit_list,
+						   file_conduit_list,
+						   device,
+						   context)) {
+		gpilot_sync_default (pfd,&stamp,pu,
+				     conduit_list,
+				     backup_conduit_list,
+				     file_conduit_list,
+				     context);
 		g_message (_("Synchronization ended")); 
 		gpilot_add_log_entry (pfd,"Synchronization completed");
 	} else {
@@ -837,11 +786,27 @@ network_device_err (GIOChannel *io_channel,
 
 #ifdef WITH_USB_VISOR
 #ifdef linux
-static const char *product_names[] =
+static const char *vendor_product_ids[] =
 {
-	"Handspring Visor",
-	"Handspring Treo",
-	"Palm Handheld",
+	"Vendor=082d ProdID=0100", /* Handspring Visor/Treo 300 */
+	"Vendor=082d ProdID=0200", /* Handspring Treo */
+	"Vendor=0830 ProdID=0001", /* Palm M500 */
+	"Vendor=0830 ProdID=0002", /* Palm M505 */
+	"Vendor=0830 ProdID=0003", /* Palm M515 */
+	"Vendor=0830 ProdID=0020", /* Palm I705 */
+	"Vendor=0830 ProdID=0040", /* Palm M125 */
+	"Vendor=0830 ProdID=0050", /* Palm M130 */
+	"Vendor=0830 ProdID=0060", /* Palm Tungsten T */
+	"Vendor=0830 ProdID=0031", /* Palm Tungsten Z */
+	"Vendor=0830 ProdID=0070", /* Palm Zire */
+	"Vendor=0830 ProdID=0080", /* Palm M100 */
+	"Vendor=054C ProdID=0038", /* Sony Clie 3.5 */
+	"Vendor=054C ProdID=0066", /* Sony Clie 4.0 */
+	"Vendor=054C ProdID=0095", /* Sony Clie S360 */
+	"Vendor=054C ProdID=009A", /* Sony Clie 4.1 */
+	"Vendor=054C ProdID=00DA", /* Sony Clie NX60 */
+	"Vendor=054C ProdID=00E9", /* Sony Clie NZ90V */
+	"Vendor=04E8 ProdID=8001", /* Samsung SCH-I330 */
 	NULL
 };
 
@@ -850,6 +815,22 @@ static gboolean product_net[] =
        FALSE,
        TRUE,
        TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
+       TRUE,
        -1
 };
 
@@ -877,13 +858,13 @@ visor_devices_in (GIOChannel *io_channel,
 	f = fopen ("/proc/bus/usb/devices", "r");
 	
 	while (fgets (line, 255, f) != NULL && !visor_exists) {
-		if (line[0] != 'S')
+		if (line[0] != 'P')
 			continue;
 		
-		for (i = 0; product_names[i] != NULL; i++) {
-			if (!strncmp (line + strlen ("S:  Product="), 
-				      product_names[i], 
-				      strlen (product_names[i]))) {
+		for (i = 0; vendor_product_ids[i] != NULL; i++) {
+			if (!strncmp (line + strlen ("P:  "), 
+				      vendor_product_ids[i], 
+				      strlen (vendor_product_ids[i]))) {
 				visor_exists = TRUE;
 				visor_net = product_net[i];
 			}
@@ -1149,6 +1130,7 @@ main (int argc, char *argv[])
 
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	/*g_log_set_always_fatal (G_LOG_LEVEL_ERROR |
 				G_LOG_LEVEL_CRITICAL |
