@@ -883,7 +883,7 @@ gpilotd_corba_notify_on(GNOME_Pilot_Daemon obj,
 	GET_AND_CHECK_CLIENT_ID_VOID(client_id,cb);
 
 	{
-		gchar *event_type;
+		gchar *event_type = NULL;
 		switch(event) {
 		case GNOME_Pilot_NOTIFY_CONNECT: 
 			event_type = g_strdup("CONNECT"); break;
@@ -932,7 +932,7 @@ gpilotd_corba_notify_off(GNOME_Pilot_Daemon obj,
 	GET_AND_CHECK_CLIENT_ID_VOID(client_id,cb);
 
 	{
-		gchar *event_type;
+		gchar *event_type = NULL;
 		switch(event) {
 		case GNOME_Pilot_NOTIFY_CONNECT: 
 			event_type = g_strdup("CONNECT"); break;
